---
name: Bug Issue
about: Report bugs and errors for the Python package open-mastr. Note that we are not the maintainers of the actual dataset. Visit https://www.marktstammdatenregister.de/MaStR to reach them.
title: Your title should make sense if said after "The issue is <your issue title>"
labels: "bug"
assignees: ''
---


## Description of the issue

Describe the problem in as much detail as possible.
Focus on the expected and current behavior. 
If necessary, create a screenshot and insert below.

## Steps to Reproduce
1.
2.
3.

## Ideas of solution

Describe possible ideas for solution and evaluate advantages and disadvantages.

## Context and Environment
* Version used: 
* Operating system: 
* Environment setup and (python) version: 

## Workflow checklist
- [ ] I have checked [the documentation](https://open-mastr.readthedocs.io/en/latest/) and confirmed this issue is not already addressed there.
- [ ] I am aware of the workflow in [CONTRIBUTING.md](https://github.com/OpenEnergyPlatform/open-MaStR/blob/production/CONTRIBUTING.md)
